@@ -2,15 +2,15 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 49685 2008-01-23 14:31:46Z cray $
+$Id: interfaces.py 51641 2008-09-06 18:47:13Z cray $
 """
 __author__  = "Elena Antusheva, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49685 $"
+__version__ = "$Revision: 51641 $"
  
 from zope.interface import Interface
 
-from zope.schema import Text, TextLine, Field, Bool, Datetime
+from zope.schema import Text, TextLine, Field, Bool, Datetime, Choice
 from zope.app.container.interfaces import IContained, IOrderedContainer
 from zope.app.container.constraints import ItemTypePrecondition
 from zope.app.container.constraints import ContainerTypesConstraint
@@ -21,16 +21,23 @@ class ISmartBannerContent ( Interface ) :
 class ISmartBannerContainerData(Interface) :
     
     use_fake_place = Bool(
-                     title=u"use_fake_place",
+                     title=u"Use fake place",
                      description=u"True if this node is expanded.",
                    )
 
     fake_place_root = TextLine(
-        title = u'fake_place_root',
+        title = u'Fake place root',
         description = u'fake_place_root',
         default = u'',
         required = False)
 
+    algorithm = Choice(
+        title = u'Algorithm',
+        description = u'Algorithm that be used to choice current banner',
+        vocabulary = 'SmartBannerAlgorithmVocabulary',
+        default = 'Random',
+    )
+
 class ISmartBannerContainer ( IOrderedContainer ) :
     """ """
     def __setitem__(name, object) :
@@ -38,4 +45,4 @@ class ISmartBannerContainer ( IOrderedContainer ) :
     __setitem__.precondition = ItemTypePrecondition(ISmartBannerContent)
     
 class ISmartBannerContainerOrdered ( ISmartBannerContainer ) :
-    """ """    
\ No newline at end of file
+    """ """
\ No newline at end of file
