@@ -2,11 +2,11 @@
 #######################################################################
 """Product class for the Zope 3 based product package
 
-$Id: smartbannernamespace.py 49685 2008-01-23 14:31:46Z cray $
+$Id: smartbannernamespace.py 51641 2008-09-06 18:47:13Z cray $
 """
 __author__  = "Elena Antusheva, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49685 $"
+__version__ = "$Revision: 51641 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
@@ -15,7 +15,7 @@ from zope.traversing.interfaces import ITraverser, ITraversable
 from zope.app.catalog.interfaces import ICatalog
 from ng.app.smartbanner.smartbannercontainer.interfaces import ISmartBannerContainer
 
-from zope.app.zapi import getUtility
+from zope.app.zapi import getUtility, getUtilitiesFor
 
 class SmartBannerNamespace(object) :
     implements(ITraversable)
@@ -24,7 +24,17 @@ class SmartBannerNamespace(object) :
         self.context = context
         self.request = request
 
-    def traverse(self,name,ignored) :
-        sbc = getUtility(ISmartBannerContainer)
-        return sbc[name]
-        
\ No newline at end of file
+    def traverse(self,key,ignored) :
+        try :
+            key,name = key.rsplit(":",1)
+        except ValueError :
+            for name, utility in getUtilitiesFor(ISmartBannerContainer) :
+                try :
+                    return utility[key]
+                except KeyError :
+                    pass
+            else :
+                raise KeyError, key                               
+        else :
+            return getUtility(ISmartBannerContainer,name=name)[key]        
+            
\ No newline at end of file
