@@ -1,19 +1,22 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""SmartBannerView class for the Zope 3 based smartbannerview package
+"""SmartBannerView class for the Zope 3 based
+ng.app.smartbanner.smartbannerview package
 
-$Id: smartbannerview.py 49685 2008-01-23 14:31:46Z cray $
+$Id: smartbannerview.py 51641 2008-09-06 18:47:13Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49685 $"
+__version__ = "$Revision: 51641 $"
+
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
 from zope.app import zapi
 from ng.app.smartbanner.smartbannercontainer.interfaces import ISmartBannerContainer
 import time
-                
+
+
 class SmartBannerView(object) :
     """ SmartbannerView
     """    
@@ -23,7 +26,6 @@ class SmartBannerView(object) :
         """ Get images from ISmartBannerContainer utility and set banners property
             from them
         """
-        lt = time.localtime()
-        lt_float = lt[3] * 60 * 60 + lt[4] * 60 + lt[5]
-        banners = [x for x in zapi.getUtility(ISmartBannerContainer).values() if x.begin_time < lt_float < x.end_time]
-        return banners
+        return (x for x in zapi.getUtility(ISmartBannerContainer).values() if x.filter())
+
+  
